@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
 import functools
 from django.contrib.auth.models import Permission
+from django.contrib.contenttypes.models import ContentType
 from django.db.models.signals import post_delete, post_save
 from pybb.profiles import PybbProfile
 from pybb.subscription import notify_topic_subscribers
 
-import os.path
-import uuid
-
 from django.db import models, transaction
 from django.core.urlresolvers import reverse
 from django.db.utils import IntegrityError
@@ -491,7 +489,7 @@ def user_saved(instance, created, **kwargs):
     try:
         add_post_permission = Permission.objects.get_by_natural_key('add_post', 'pybb', 'post')
         add_topic_permission = Permission.objects.get_by_natural_key('add_topic', 'pybb', 'topic')
-    except Permission.DoesNotExist:
+    except Permission.DoesNotExist, ContentType.DoesNotExist:
         return
     instance.user_permissions.add(add_post_permission, add_topic_permission)
     instance.save()
