@@ -22,6 +22,7 @@ from pybb.util import build_cache_key
 
 try:
     from pure_pagination import Paginator
+    pure_pagination = True
 except ImportError:
     # the simplest emulation of django-pure-pagination behavior
     from django.core.paginator import Paginator, Page
@@ -29,6 +30,7 @@ except ImportError:
         def querystring(self):
             return 'page=%s' % self
     Page.pages = lambda self: [PageRepr(i) for i in range(1, self.paginator.num_pages + 1)]
+    pure_pagination = False
 
 from pybb.models import Category, Forum, Topic, Post, TopicReadTracker, ForumReadTracker, PollAnswerUser
 from pybb.forms import PostForm, AdminPostForm, AttachmentFormSet, PollAnswerFormSet, PollForm
@@ -42,6 +44,14 @@ User = util.get_user_model()
 username_field = util.get_username_field()
 
 
+class PaginatorMixin(object):
+    def get_paginator(self, queryset, per_page, orphans=0, allow_empty_first_page=True, **kwargs):
+        kwargs = {}
+        if pure_pagination:
+            kwargs['request'] = self.request
+        return Paginator(queryset, per_page, orphans=0, allow_empty_first_page=True, **kwargs)
+
+
 class RedirectToLoginMixin(object):
     """ mixin which redirects to settings.LOGIN_URL if the view encounters an PermissionDenied exception
         and the user is not authenticated. Views inheriting from this need to implement
@@ -103,12 +113,11 @@ class CategoryView(RedirectToLoginMixin, generic.DetailView):
         return ctx
 
 
-class ForumView(RedirectToLoginMixin, generic.ListView):
+class ForumView(RedirectToLoginMixin, PaginatorMixin, generic.ListView):
 
     paginate_by = defaults.PYBB_FORUM_PAGE_SIZE
     context_object_name = 'topic_list'
     template_name = 'pybb/forum.html'
-    paginator_class = Paginator
 
     def get_login_redirect_url(self):
         return reverse('pybb:forum', args=(self.kwargs['pk'],))
@@ -129,12 +138,11 @@ class ForumView(RedirectToLoginMixin, generic.ListView):
         return qs
 
 
-class LatestTopicsView(generic.ListView):
+class LatestTopicsView(PaginatorMixin, generic.ListView):
 
     paginate_by = defaults.PYBB_FORUM_PAGE_SIZE
     context_object_name = 'topic_list'
     template_name = 'pybb/latest_topics.html'
-    paginator_class = Paginator
 
     def get_queryset(self):
         qs = Topic.objects.all().select_related()
@@ -142,11 +150,10 @@ class LatestTopicsView(generic.ListView):
         return qs.order_by('-updated')
 
 
-class TopicView(RedirectToLoginMixin, generic.ListView):
+class TopicView(RedirectToLoginMixin, PaginatorMixin, generic.ListView):
     paginate_by = defaults.PYBB_TOPIC_PAGE_SIZE
     template_object_name = 'post_list'
     template_name = 'pybb/topic.html'
-    paginator_class = Paginator
 
     def get_login_redirect_url(self):
         return reverse('pybb:topic', args=(self.kwargs['pk'],))
@@ -212,7 +219,7 @@ class TopicView(RedirectToLoginMixin, generic.ListView):
             ctx['form'] = PostForm(topic=self.topic)
         else:
             ctx['form'] = None
-        if defaults.PYBB_ATTACHMENT_ENABLE:
+        if perms.may_attach_files(self.request.user):
             aformset = AttachmentFormSet()
             ctx['aformset'] = aformset
         if defaults.PYBB_FREEZE_FIRST_POST:
@@ -263,9 +270,9 @@ class PostEditMixin(object):
 
     def get_context_data(self, **kwargs):
         ctx = super(PostEditMixin, self).get_context_data(**kwargs)
-        if defaults.PYBB_ATTACHMENT_ENABLE and (not 'aformset' in kwargs):
+        if perms.may_attach_files(self.request.user) and (not 'aformset' in kwargs):
             ctx['aformset'] = AttachmentFormSet(instance=self.object if getattr(self, 'object') else None)
-        if 'pollformset' not in kwargs:
+        if perms.may_create_poll(self.request.user) and ('pollformset' not in kwargs):
             ctx['pollformset'] = PollAnswerFormSet(instance=self.object.topic if getattr(self, 'object') else None)
         return ctx
 
@@ -275,26 +282,29 @@ class PostEditMixin(object):
         save_poll_answers = False
         self.object = form.save(commit=False)
 
-        if defaults.PYBB_ATTACHMENT_ENABLE:
+        if perms.may_attach_files(self.request.user):
             aformset = AttachmentFormSet(self.request.POST, self.request.FILES, instance=self.object)
             if aformset.is_valid():
                 save_attachments = True
             else:
                 success = False
         else:
-            aformset = AttachmentFormSet()
+            aformset = None
 
-        pollformset = PollAnswerFormSet()
-        if getattr(self, 'forum', None) or self.object.topic.head == self.object:
-            if self.object.topic.poll_type != Topic.POLL_TYPE_NONE:
-                pollformset = PollAnswerFormSet(self.request.POST, instance=self.object.topic)
-                if pollformset.is_valid():
-                    save_poll_answers = True
+        if perms.may_create_poll(self.request.user):
+            pollformset = PollAnswerFormSet()
+            if getattr(self, 'forum', None) or self.object.topic.head == self.object:
+                if self.object.topic.poll_type != Topic.POLL_TYPE_NONE:
+                    pollformset = PollAnswerFormSet(self.request.POST, instance=self.object.topic)
+                    if pollformset.is_valid():
+                        save_poll_answers = True
+                    else:
+                        success = False
                 else:
-                    success = False
-            else:
-                self.object.topic.poll_question = None
-                self.object.topic.poll_answers.all().delete()
+                    self.object.topic.poll_question = None
+                    self.object.topic.poll_answers.all().delete()
+        else:
+            pollformset = None
 
         if success:
             self.object.topic.save()
@@ -356,8 +366,9 @@ class AddPostView(PostEditMixin, generic.CreateView):
                            ip=ip, initial={}))
         if getattr(self, 'quote', None):
             form_kwargs['initial']['body'] = self.quote
-        if self.user.is_staff:
+        if perms.may_post_as_admin(self.user):
             form_kwargs['initial']['login'] = getattr(self.user, username_field)
+        form_kwargs['may_create_poll'] = perms.may_create_poll(self.user)
         return form_kwargs
 
     def get_context_data(self, **kwargs):
@@ -384,6 +395,11 @@ class EditPostView(PostEditMixin, generic.UpdateView):
     def dispatch(self, request, *args, **kwargs):
         return super(EditPostView, self).dispatch(request, *args, **kwargs)
 
+    def get_form_kwargs(self):
+        form_kwargs = super(EditPostView, self).get_form_kwargs()
+        form_kwargs['may_create_poll'] = perms.may_create_poll(self.request.user)
+        return form_kwargs
+
     def get_object(self, queryset=None):
         post = super(EditPostView, self).get_object(queryset)
         if not perms.may_edit_post(self.request.user, post):
@@ -407,10 +423,9 @@ class UserView(generic.DetailView):
         return ctx
 
 
-class UserPosts(generic.ListView):
+class UserPosts(PaginatorMixin, generic.ListView):
     model = Post
     paginate_by = defaults.PYBB_TOPIC_PAGE_SIZE
-    paginator_class = Paginator
     template_name = 'pybb/user_posts.html'
 
     def dispatch(self, request, *args, **kwargs):
@@ -431,10 +446,9 @@ class UserPosts(generic.ListView):
         return context
 
 
-class UserTopics(generic.ListView):
+class UserTopics(PaginatorMixin, generic.ListView):
     model = Topic
     paginate_by = defaults.PYBB_FORUM_PAGE_SIZE
-    paginator_class = Paginator
     template_name = 'pybb/user_topics.html'
 
     def dispatch(self, request, *args, **kwargs):
